import{d as u,ez as b,H as f,b as y,c as g,u as _}from"./outputWidgets.9a4dffd5.js";import{a as w}from"./asyncComputed.947a021a.js";import"./router.e9c58c63.js";import{M as m}from"./member.ffd0cf0e.js";import"./columns.2487afd8.js";import{C as I}from"./CrudView.32e9e362.js";import"./Title.72e90637.js";import"./index.a351ac5c.js";import"./gateway.a8fa6711.js";import"./activeRecord.6b2e89dc.js";import"./pubsub.25596209.js";import"./index.f4ac7424.js";import"./icons.d935dec9.js";import"./index.0d204717.js";import"./Form.0ea0ca53.js";import"./url.152c5826.js";import"./index.c64df437.js";import"./index.c4327f7e.js";import"./index.d0b58c73.js";import"./index.3ecad98a.js";import"./index.0e22fd42.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="6313aeba-5adb-4804-b4c8-c48e608c3f09",e._sentryDebugIdIdentifier="sentry-dbid-6313aeba-5adb-4804-b4c8-c48e608c3f09")}catch{}})();const J=u({__name:"Members",setup(e){const r=b().params.organizationId,n=[{key:"email",label:"Email"}],s=async t=>{await m.create(r,t.email),d()},{loading:l,result:p,refetch:d}=w(()=>m.list(r)),c=f(()=>{var t,a;return{columns:[{name:"Email"},{name:"Role"}],rows:(a=(t=p.value)==null?void 0:t.map(i=>({key:i.email,cells:[{text:i.email},{text:i.role}]})))!=null?a:[]}});return(t,a)=>(y(),g(I,{"entity-name":"members",loading:_(l),title:"Organization members",description:"List all organization members.","empty-title":"No members yet",table:c.value,"create-button-text":"Add members",fields:n,onCreate:s},null,8,["loading","table"]))}});export{J as default};
//# sourceMappingURL=Members.1ad47df6.js.map
