import{d as y,ey as b,H as h,b as g,c as w,u as _}from"./outputWidgets.9a4dffd5.js";import{e as C,a as F,b as k}from"./icons.d935dec9.js";import{a as x}from"./asyncComputed.947a021a.js";import{F as d}from"./forms.ee974765.js";import{C as v}from"./CrudView.32e9e362.js";import{a as D}from"./ant-design.edc4db28.js";import"./activeRecord.6b2e89dc.js";import"./pubsub.25596209.js";import"./index.0d204717.js";import"./Title.72e90637.js";import"./Form.0ea0ca53.js";import"./router.e9c58c63.js";import"./index.a351ac5c.js";import"./url.152c5826.js";import"./index.c64df437.js";import"./index.c4327f7e.js";import"./index.d0b58c73.js";import"./index.3ecad98a.js";import"./index.0e22fd42.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[r]="a699c6d1-4e40-4a06-9393-dd3cd3ebcef9",a._sentryDebugIdIdentifier="sentry-dbid-a699c6d1-4e40-4a06-9393-dd3cd3ebcef9")}catch{}})();const G=y({__name:"Forms",setup(a){const r=b(),{loading:s,result:n,refetch:m}=x(()=>d.list()),c=({key:e})=>r.push({path:`/_editor/form/${encodeURIComponent(e)}`}),l=async({key:e})=>{var o,t;await((t=(o=n.value)==null?void 0:o.find(i=>i.path===e))==null?void 0:t.duplicate()),m()},p=async()=>{const e=await d.create();c({key:e.path})},u=async({key:e})=>{var o,t;await D("Are you sure you want to delete this form?")&&(await((t=(o=n.value)==null?void 0:o.find(i=>i.path===e))==null?void 0:t.delete()),m())},f=h(()=>{var e,o;return{columns:[{name:"Form Name"},{name:"Path"},{name:"Actions",align:"right"}],rows:(o=(e=n.value)==null?void 0:e.map(t=>({key:t.path,cells:[{text:t.title,link:`/_editor/form/${encodeURIComponent(t.path)}`},{text:t.path},{text:"",actions:[{icon:C,label:"Edit Form",onClick:c},{icon:F,label:"Duplicate",onClick:l},{icon:k,label:"Delete",onClick:u,dangerous:!0}]}]})))!=null?o:[]}});return(e,o)=>(g(),w(v,{loading:_(s),title:"Dynamic Python forms",description:"Create forms with advanced logic, easy integrations and custom branding.","create-button-text":"Create Form","empty-title":"No forms here yet","video-url":"https://www.youtube.com/embed/p6xf8PxL2Yg",table:f.value,"entity-name":"Form",onCreate:p},null,8,["loading","table"]))}});export{G as default};
//# sourceMappingURL=Forms.1d4d916a.js.map
