import{v as r,a as i,b as a,c,i as d,T as p,j as u,P as _,C as f,M as b,s as l,k as s,l as g,m,n as y,p as v}from"./outputWidgets.9a4dffd5.js";import{u as w,a as o}from"./index.7e030f20.js";import"./pubsub.25596209.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="cb1c30f7-6e54-477d-b414-820d11eb237c",e._sentryDebugIdIdentifier="sentry-dbid-cb1c30f7-6e54-477d-b414-820d11eb237c")}catch{}})();const h={};function I(e,t){const n=i("router-view");return a(),c(n,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const k=r(h,[["render",I]]);class x{static init(){setInterval(()=>fetch("/_version"),20*1e3)}}(async()=>{await w();const e=d({render:()=>g(k)});p.init(),u(e,o),x.init(),e.use(o),e.use(_),e.mount("#app"),e.component("VSelect",f),e.component("Markdown",b),e.component("Message",l),s(e,m),s(e,y),s(e,v)})();
//# sourceMappingURL=player.0f44ee13.js.map
