import{cC as d}from"./outputWidgets.9a4dffd5.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="b4336ad8-8631-4c09-bd92-a6205a5b775c",e._sentryDebugIdIdentifier="sentry-dbid-b4336ad8-8631-4c09-bd92-a6205a5b775c")}catch{}})();const t=(e,r)=>{d.error({message:e,description:r})};export{t as p};
//# sourceMappingURL=popupNotifcation.5e27ab9c.js.map
