import{d as g,ey as v,ez as k,r as b,b as r,c as s,w as a,u as e,f as u,ev as n}from"./outputWidgets.9a4dffd5.js";import{S as j,L as w}from"./SmartConsole.2f597edf.js";import{a as x}from"./asyncComputed.947a021a.js";import{J as I}from"./jobs.9fc486b1.js";import{_ as B}from"./SaveButton.vue_vue_type_script_setup_true_lang.9f93be5c.js";import{_ as C}from"./DocsButton.vue_vue_type_script_setup_true_lang.b0c540d5.js";import{B as S}from"./BaseLayout.a71d4fa9.js";import{_ as T,a as D}from"./JobSettings.vue_vue_type_script_setup_true_lang.0d37b3de.js";import{c as R}from"./index.c2be78ce.js";import{A as _,T as $}from"./TabPane.aa41b762.js";import"./forms.ee974765.js";import"./activeRecord.6b2e89dc.js";import"./pubsub.25596209.js";import"./dashes.8f97fb72.js";import"./runnerData.8cacc2f4.js";import"./hooks.350ac392.js";import"./workspaces.9b724498.js";import"./url.152c5826.js";import"./icons.d935dec9.js";import"./Title.72e90637.js";import"./index.d0b58c73.js";import"./uuid.649f8e0e.js";import"./ant-design.edc4db28.js";import"./RunButton.vue_vue_type_script_setup_true_lang.95e06f26.js";import"./index.5ac52d51.js";import"./index.c4327f7e.js";import"./dayjs.66de0854.js";import"./Form.0ea0ca53.js";import"./index.0e22fd42.js";(function(){try{var i=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},m=new Error().stack;m&&(i._sentryDebugIds=i._sentryDebugIds||{},i._sentryDebugIds[m]="896b6a17-7ebf-43a8-bd4e-51d3a86920c4",i._sentryDebugIdIdentifier="sentry-dbid-896b6a17-7ebf-43a8-bd4e-51d3a86920c4")}catch{}})();const me=g({__name:"JobEditor",setup(i){const m=v(),l=k(),c=b(null),o=b("test");function y(){m.push({name:"jobs"})}const{result:t}=x(()=>I.get(l.params.jobId)),f=w.create();return(A,d)=>(r(),s(S,null,{navbar:a(()=>[e(t)?(r(),s(e(R),{key:0,title:e(t).title,style:{padding:"5px 10px"},onBack:y},{footer:a(()=>[u(e($),{"active-key":o.value,"onUpdate:activeKey":d[0]||(d[0]=p=>o.value=p)},{default:a(()=>[u(e(_),{key:"test",tab:"Test"}),u(e(_),{key:"settings",tab:"Settings"})]),_:1},8,["active-key"])]),extra:a(()=>[u(C),o.value==="settings"?(r(),s(B,{key:0,model:e(t)},null,8,["model"])):n("",!0)]),_:1},8,["title"])):n("",!0)]),content:a(()=>[e(t)&&o.value==="test"?(r(),s(T,{key:0,ref_key:"tester",ref:c,job:e(t),"log-service":e(f)},null,8,["job","log-service"])):n("",!0),e(t)&&o.value==="settings"?(r(),s(D,{key:1,job:e(t)},null,8,["job"])):n("",!0)]),footer:a(()=>{var p;return[e(t)&&o.value==="test"?(r(),s(j,{key:0,runtime:"forms","log-service":e(f),onRestart:(p=c.value)==null?void 0:p.test},null,8,["log-service","onRestart"])):n("",!0)]}),_:1}))}});export{me as default};
//# sourceMappingURL=JobEditor.08029b17.js.map
