import{R as t}from"./Title.72e90637.js";import{E as n}from"./outputWidgets.9a4dffd5.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new Error().stack;d&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[d]="484880c2-8ffe-4db9-a301-82d30d8cc0ba",e._sentryDebugIdIdentifier="sentry-dbid-484880c2-8ffe-4db9-a301-82d30d8cc0ba")}catch{}})();const s=n(t);export{s as A};
//# sourceMappingURL=index.d0b58c73.js.map
