import{x as s}from"./icons.d935dec9.js";import{d as r,a as c,b as i,et as f,f as d,u as _,aI as l,v as u}from"./outputWidgets.9a4dffd5.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="22a7c7ea-6a59-4cfa-937a-930b7f5f89f9",e._sentryDebugIdIdentifier="sentry-dbid-22a7c7ea-6a59-4cfa-937a-930b7f5f89f9")}catch{}})();const p=r({__name:"BackButton",emits:["exitFullscreenPreview"],setup(e,{emit:t}){return(a,n)=>{const o=c("icon");return i(),f("button",{class:"back-btn",onClick:n[0]||(n[0]=b=>t("exitFullscreenPreview"))},[d(o,{class:"icon",path:_(s),width:"20",height:"20",fill:"#5A677A"},null,8,["path"]),l(" Editor ")])}}});const v=u(p,[["__scopeId","data-v-eaeb3a6e"]]);export{v as B};
//# sourceMappingURL=BackButton.28068072.js.map
