import"./outputWidgets.9a4dffd5.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="9bd33ccd-63f6-4bca-9f8a-e9416ea5ac36",e._sentryDebugIdIdentifier="sentry-dbid-9bd33ccd-63f6-4bca-9f8a-e9416ea5ac36")}catch{}})();function o(e){return e.charAt(0).toUpperCase()+e.slice(1)}function s(e,r){const n=e.toLocaleLowerCase().replace(/[^a-z0-9]/g,"_").replace(/_+/g,"_");return r?n:n.replace(/_$/,"")}export{o as c,s as n};
//# sourceMappingURL=string.2c28b0b0.js.map
