import{d as o,b as s,c as r,w as c,aI as i,u as d,c0 as p}from"./outputWidgets.9a4dffd5.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="ba3e9e17-ba88-40e3-a059-dc07469da2ac",t._sentryDebugIdIdentifier="sentry-dbid-ba3e9e17-ba88-40e3-a059-dc07469da2ac")}catch{}})();class f{async get(){return(await fetch("/_editor/api/login")).json()}async create(e){return(await fetch("/_editor/api/login",{method:"POST",headers:{"Content-Type":"application/json"},body:JSON.stringify({token:e})})).json()}async delete(){await fetch("/_editor/api/login",{method:"DELETE"})}async getProjectInfo(){return(await fetch("/_editor/api/project-info")).json()}}const l=new f,_=o({__name:"DocsButton",props:{path:{}},setup(t){return(e,n)=>{var a;return s(),r(d(p),{class:"docs-button",href:`https://docs.abstra.io/${(a=e.path)!=null?a:""}`,target:"_blank"},{default:c(()=>[i(" Docs ")]),_:1},8,["href"])}}});export{_,l};
//# sourceMappingURL=DocsButton.vue_vue_type_script_setup_true_lang.b0c540d5.js.map
