import{v as t,b as s,et as o}from"./outputWidgets.9a4dffd5.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="5f2b8d1c-f17a-4bf5-95b7-202bd1762966",e._sentryDebugIdIdentifier="sentry-dbid-5f2b8d1c-f17a-4bf5-95b7-202bd1762966")}catch{}})();const r={},d={class:"organization-settings"};function i(e,n){return s(),o("div",d,"Organization settings")}const c=t(r,[["render",i]]);export{c as default};
//# sourceMappingURL=OrganizationSettings.42ea2d85.js.map
