var f=Object.defineProperty;var b=(a,e,t)=>e in a?f(a,e,{enumerable:!0,configurable:!0,writable:!0,value:t}):a[e]=t;var d=(a,e,t)=>(b(a,typeof e!="symbol"?e+"":e,t),t);import{d as g,ez as w,H as v,b as k,c as $,u as C}from"./outputWidgets.9a4dffd5.js";import{a as I}from"./asyncComputed.947a021a.js";import"./router.e9c58c63.js";import{C as l}from"./gateway.a8fa6711.js";import{A as _}from"./activeRecord.6b2e89dc.js";import"./columns.2487afd8.js";import{k as j}from"./icons.d935dec9.js";import{C as A}from"./CrudView.32e9e362.js";import"./Title.72e90637.js";import"./index.a351ac5c.js";import"./pubsub.25596209.js";import"./index.f4ac7424.js";import"./index.0d204717.js";import"./Form.0ea0ca53.js";import"./url.152c5826.js";import"./index.c64df437.js";import"./index.c4327f7e.js";import"./index.d0b58c73.js";import"./index.3ecad98a.js";import"./index.0e22fd42.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[e]="e7a0fb37-c67e-4a14-b8ad-eaccaa92c10f",a._sentryDebugIdIdentifier="sentry-dbid-e7a0fb37-c67e-4a14-b8ad-eaccaa92c10f")}catch{}})();class P{constructor(){d(this,"urlPath","env-vars")}async create(e){return l.post(`projects/${e.projectId}/${this.urlPath}`,{name:e.name,value:e.value})}async delete(e,t){await l.delete(`projects/${e}/${this.urlPath}/${t}`)}async list(e){return l.get(`projects/${e}/${this.urlPath}`)}async get(e){return l.get(`${this.urlPath}/${e}`)}async update(e,t){return l.patch(`${this.urlPath}/${e}`,t)}}const n=new P;class s{constructor(e,t){d(this,"record");this.projectId=e,this.record=_.create(n,t,"id")}static async list(e){return(await n.list(e)).map(r=>new s(e,r))}static async create(e,t,r){const o=await n.create({projectId:e,name:t,value:r});return new s(e,o)}static async get(e,t){const r=await n.get(t);return new s(e,r)}static async update(e,t,r){const o=await n.update(t,r);return new s(e,o)}get key(){return this.record.get("name")}get value(){return this.record.get("value")}set value(e){this.record.set("value",e)}async save(){await this.record.save()}async delete(){await n.delete(this.projectId,this.key)}hasChanges(){return this.record.hasChanges()}}const X=g({__name:"EnvVars",setup(a){const t=w().params.projectId,{loading:r,result:o,refetch:p}=I(()=>s.list(t)),m=[{label:"Variable name",key:"key"},{label:"Variable value",key:"value",type:"password"}];async function y({key:i,value:c}){await s.create(t,i,c),p()}const h=v(()=>{var i,c;return{columns:[{name:"Key"},{name:"Actions",align:"right"}],rows:(c=(i=o.value)==null?void 0:i.map(u=>({key:u.key,cells:[{text:u.key},{text:"Actions",actions:[{icon:j,label:"Delete",async onClick(){await u.delete(),p()},dangerous:!0}]}]})))!=null?c:[]}});return(i,c)=>(k(),$(A,{"entity-name":"Env var",loading:C(r),title:"Environment Variables",description:"Set environment variables for your project.","empty-title":"No environment variables set",table:h.value,"create-button-text":"Add Environment Variable",fields:m,onCreate:y},null,8,["loading","table"]))}});export{X as default};
//# sourceMappingURL=EnvVars.9d4d59f5.js.map
