import"./outputWidgets.9a4dffd5.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="868348af-18ef-4a73-983b-bf47672a56ca",e._sentryDebugIdIdentifier="sentry-dbid-868348af-18ef-4a73-983b-bf47672a56ca")}catch{}})();const f=e=>{try{return new URL(e),!0}catch{return!1}};export{f as i};
//# sourceMappingURL=url.152c5826.js.map
