import{S as p}from"./Sidebar.05b85fdb.js";import{_ as c}from"./Navbar.vue_vue_type_script_setup_true_lang.abe838a3.js";import{G as l,H as d,I as u}from"./icons.d935dec9.js";import{d as b,ez as f,H as g,a as _,b as y,c as v,w as t,f as r}from"./outputWidgets.9a4dffd5.js";import{a as w}from"./asyncComputed.947a021a.js";import"./router.e9c58c63.js";import{O as z}from"./organization.ab53ea01.js";import"./columns.2487afd8.js";import{B as h}from"./BaseLayout.a71d4fa9.js";import"./Tooltip.99b12d24.js";import"./logo.084e5d7c.js";import"./index.0d204717.js";import"./Title.72e90637.js";import"./index.0e22fd42.js";import"./index.c2be78ce.js";import"./index.a351ac5c.js";import"./gateway.a8fa6711.js";import"./activeRecord.6b2e89dc.js";import"./pubsub.25596209.js";import"./index.f4ac7424.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="538998e7-1c01-4d51-9f21-e49247aef75b",e._sentryDebugIdIdentifier="sentry-dbid-538998e7-1c01-4d51-9f21-e49247aef75b")}catch{}})();const J=b({__name:"Organization",setup(e){const n=f().params.organizationId,{result:a}=w(()=>z.get(n)),i=g(()=>a.value?[{label:"My organizations",path:"/organizations"},{label:a.value.name,path:`/organizations/${a.value.id}`}]:void 0),s=[{name:"Organization",items:[{name:"Projects",icon:l,path:"projects"},{name:"Members",icon:d,path:"members"},{name:"Billing",icon:u,path:"billing",unavailable:!0}]}];return(I,B)=>{const m=_("router-view");return y(),v(h,null,{navbar:t(()=>[r(c,{breadcrumb:i.value},null,8,["breadcrumb"])]),sidebar:t(()=>[r(p,{class:"sidebar",sections:s})]),content:t(()=>[r(m)]),_:1})}}});export{J as default};
//# sourceMappingURL=Organization.95821b23.js.map
