import{d as b,ey as g,ez as v,r as k,b as r,c as s,w as a,u as e,f as u,ev as n}from"./outputWidgets.9a4dffd5.js";import{S as h,L as w}from"./SmartConsole.2f597edf.js";import{a as x}from"./asyncComputed.947a021a.js";import{H as B}from"./hooks.350ac392.js";import{_ as C}from"./SaveButton.vue_vue_type_script_setup_true_lang.9f93be5c.js";import{_ as H}from"./DocsButton.vue_vue_type_script_setup_true_lang.b0c540d5.js";import{B as I}from"./BaseLayout.a71d4fa9.js";import{_ as S,a as T}from"./HookSettings.vue_vue_type_script_setup_true_lang.822dd6b3.js";import{c as D}from"./index.c2be78ce.js";import{A as _,T as R}from"./TabPane.aa41b762.js";import"./forms.ee974765.js";import"./activeRecord.6b2e89dc.js";import"./pubsub.25596209.js";import"./dashes.8f97fb72.js";import"./runnerData.8cacc2f4.js";import"./jobs.9fc486b1.js";import"./workspaces.9b724498.js";import"./url.152c5826.js";import"./icons.d935dec9.js";import"./Title.72e90637.js";import"./index.d0b58c73.js";import"./uuid.649f8e0e.js";import"./ant-design.edc4db28.js";import"./StageRunSelector.vue_vue_type_script_setup_true_lang.08b0df03.js";import"./RunButton.vue_vue_type_script_setup_true_lang.95e06f26.js";import"./index.5f8ac887.js";import"./index.3ecad98a.js";import"./CollapsePanel.a49bdae4.js";import"./index.0e22fd42.js";import"./index.c64df437.js";import"./index.c4327f7e.js";import"./Form.0ea0ca53.js";(function(){try{var i=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},m=new Error().stack;m&&(i._sentryDebugIds=i._sentryDebugIds||{},i._sentryDebugIds[m]="14716ac5-a07b-4f23-93bb-178fb1069551",i._sentryDebugIdIdentifier="sentry-dbid-14716ac5-a07b-4f23-93bb-178fb1069551")}catch{}})();const le=b({__name:"HookEditor",setup(i){const m=g(),l=v(),f=k(null),o=k("test");function y(){m.push({name:"hooks"})}const{result:t}=x(()=>B.get(l.params.hookPath)),c=w.create();return($,d)=>(r(),s(I,null,{navbar:a(()=>[e(t)?(r(),s(e(D),{key:0,title:e(t).title,style:{padding:"5px 10px"},onBack:y},{footer:a(()=>[u(e(R),{"active-key":o.value,"onUpdate:activeKey":d[0]||(d[0]=p=>o.value=p)},{default:a(()=>[u(e(_),{key:"test",tab:"Test"}),u(e(_),{key:"settings",tab:"Settings"})]),_:1},8,["active-key"])]),extra:a(()=>[u(H,{path:"hooks"}),o.value==="settings"?(r(),s(C,{key:0,model:e(t)},null,8,["model"])):n("",!0)]),_:1},8,["title"])):n("",!0)]),content:a(()=>[e(t)&&o.value==="test"?(r(),s(S,{key:0,ref_key:"tester",ref:f,hook:e(t),"log-service":e(c)},null,8,["hook","log-service"])):n("",!0),e(t)&&o.value==="settings"?(r(),s(T,{key:1,hook:e(t)},null,8,["hook"])):n("",!0)]),footer:a(()=>{var p;return[e(t)&&o.value==="test"?(r(),s(h,{key:0,runtime:"forms","log-service":e(c),onRestart:(p=f.value)==null?void 0:p.runHook},null,8,["log-service","onRestart"])):n("",!0)]}),_:1}))}});export{le as default};
//# sourceMappingURL=HookEditor.449a2e12.js.map
